@@ -8,7 +8,10 @@ import pip
 from django.core.management.base import BaseCommand, CommandError
 
 try:
-    from pip._internal.download import PipSession
+    try:
+        from pip._internal.network.session import PipSession
+    except ImportError:
+        from pip._internal.download import PipSession
     from pip._internal.req.req_file import parse_requirements
     from pip._internal.utils.misc import get_installed_distributions
 except ImportError:
@@ -130,9 +133,7 @@ class Command(BaseCommand):
         return LooseVersion(available[0]) if available else None
 
     def check_pypi(self):
-        """
-        If the requirement is frozen to pypi, check for a new version.
-        """
+        """If the requirement is frozen to pypi, check for a new version."""
         for dist in get_installed_distributions():
             name = dist.project_name
             if name in self.reqs.keys():
